pub enum Code {
InvalidInput,
InvalidTimeSlotId,
ScheduledPackageAlreadyExists,
ScheduleWindowExpired,
RetryableAfterGettingNewSlots,
TimeSlotNotAvailable,
ResourceNotFound,
InvalidOrderState,
RegionNotSupported,
OrderNotEligibleForRescheduling,
InternalServerError,
}Expand description
Code : An error code that identifies the type of error that occurred. The error codes listed below are specific to the Easy Ship section. An error code that identifies the type of error that occurred. The error codes listed below are specific to the Easy Ship section.
Variants
InvalidInput
InvalidTimeSlotId
ScheduledPackageAlreadyExists
ScheduleWindowExpired
RetryableAfterGettingNewSlots
TimeSlotNotAvailable
ResourceNotFound
InvalidOrderState
RegionNotSupported
OrderNotEligibleForRescheduling
InternalServerError